# digicom

## What it is

This project is a collection of equations, calculations, and static variables
used in digital signals and communications.

## How to use

Most of the function in this module as oneline anonymous functions, the input
and output for each function are self explanitory.

## Install

##### Local
```bash
$ pip install -r requiremnts.txt
$ pip install digicom/.
```

##### pip via PyPi
```bash
$ pip install digicom
```
